BitCash is a fork of Ofek's Bit.

Maintainers
-----------

- Teran McKinney

Contributors
------------

- Shawn A. Wilson aka "lannocc" [http://lanno.cc] for Alpha Griffin

- Corentin Mercier [http://mercier.link/]

- Thomas Martin aka "Gz75y45ms3kc"

Any PGP key fingerprints are enclosed in parentheses.

Ofek Lev <ofekmeister@gmail.com> (FFB6 B92B 30B1 7848 546E 9912 972F E913 DAD5 A46E)

